package gomoku;

import java.util.List;

import javafx.application.Application;
import javafx.application.Application.Parameters;
import javafx.fxml.FXMLLoader;
import javafx.stage.Stage;
import javafx.scene.Parent;
import javafx.scene.Scene;
import javafx.scene.layout.BorderPane;


public class Main extends Application {
	@Override
	public void start(Stage primaryStage) {
		try {
			Parameters params = getParameters();
			List<String> args = params.getRaw();
			Game game = null;
			if (args.size() > 0) {
				if (args.size() < 2) {
					System.out.println("usage: program player1 player2 [logfile] [boardsize]");
					System.out.println("where player1 and player2 are the class names (without .java extension).");
					System.out.println("into optional logfile will be written game moves' log.");
					System.out.println("boardsize 10 or 20, 10 is default.");
					System.exit(0);
				}
				Player[] players = new Player[2];
				for (int i = 0; i < 2; i++) {
					ClassLoader classLoader = Main.class.getClassLoader();
					try {
						Class<?> studentClass = classLoader.loadClass("gomoku.players." + args.get(i));
						Object s = studentClass.newInstance();
						System.out.println(s);
						ComputerStrategy cs = (ComputerStrategy)s;
						Player p = new ComputerPlayer(cs);
						players[i] = p;
					} catch (ClassNotFoundException e) {
						System.out.println("Class " + args.get(i) + " not found.");
						System.exit(1);
					}
				}
				int size = 10;
				if (args.size() > 3) {
					size = Integer.parseInt(args.get(3));
				}
				game = new Game(players[0], players[1], size, size);
				System.out.println("game for two");
				if (args.size() > 2) {
					System.out.println("with moves log");
					game.setHistoryLogFilename(args.get(2));
				}
			} else {
				game = new Game(10, 10);
			}

			FXMLLoader loader = new FXMLLoader(getClass().getResource("Gomoku.fxml"));
			GomokuController c = new GomokuController(game);
			loader.setController(c);
			Parent root = (Parent)loader.load();

			Scene scene = new Scene(root);
			scene.getStylesheets().add(getClass().getResource("application.css").toExternalForm());
			
			primaryStage.setTitle("GoMoku v0.6 (2014-12-29)");
			primaryStage.setScene(scene);
			primaryStage.show();
		} catch(Exception e) {
			e.printStackTrace();
		}
		
	}
	
	public static void main(String[] args) {
		launch(args);
	}
}
